@@ -161,7 +161,11 @@ def _module(proto: str) -> ModuleType:
     :return: Protobuf compiled Python module
     :rtype: ModuleType
     """
-    return import_module(proto.replace(".proto", "_pb2").replace("/", "."))
+    if proto.endswith('.proto'):
+        no_extension = f'{proto[:-len(".proto")]}_pb2'
+    else:
+        no_extension = proto
+    return import_module(no_extension.replace("/", "."))
 
 
 # -- Diagram builder
@@ -176,7 +180,11 @@ class Diagram:
     def from_file(self, proto_file: str):
         if not proto_file:
             raise ValueError("Missing proto file!")
-        self._proto_module = _module(proto_file)
+        try:
+            self._proto_module = _module(proto_file)
+        except ModuleNotFoundError as e:
+            logger.error(f'Failed to import {proto_file}')
+            raise e
         logger.info(f"Imported: {proto_file}")
         return self
 
@@ -221,7 +229,6 @@ class Diagram:
               help='Compiled Python proto module (e.g. some.package.ws_compiled_pb2).')
 @click.option('--output', type=PathPath(file_okay=False), required=True,
               help='Output directory.')
-@click.option('--fullname')
 def main(proto: str, output: Path) -> None:
     Diagram() \
         .from_file(proto) \
